@@ -44,6 +44,8 @@ pub mod mem;
 pub mod misc;
 // WIP
 // pub mod rt;
+pub mod atomic;
+pub mod cfg;
 pub mod ptr;
 pub mod shared;
 pub mod thread;
